@@ -9,6 +9,9 @@ from rclone_python import utils
 from rclone_python.hash_types import HashTypes
 from rclone_python.remote_types import RemoteTypes
 
+# debug flag enables/disables raw output of rclone progresses in the terminal
+DEBUG = False
+
 
 def __check_installed(func):
     @wraps(func)
@@ -137,6 +140,38 @@ def copy(
     if args is None:
         args = []
 
+    _rclone_transfer_operation(
+        in_path,
+        out_path,
+        ignore_existing=ignore_existing,
+        command="rclone copy",
+        command_descr="Copying",
+        show_progress=show_progress,
+        listener=listener,
+        args=args,
+    )
+
+
+def copyto(
+    in_path: str,
+    out_path: str,
+    ignore_existing=False,
+    show_progress=True,
+    listener: Callable[[Dict], None] = None,
+    args=None,
+):
+    """
+    Copies a file or a directory from a src path to a destination path and is typically used when renaming a file is necessary.
+    :param in_path: The source path to use. Specify the remote with 'remote_name:path_on_remote'
+    :param out_path: The destination path to use. Specify the remote with 'remote_name:path_on_remote'
+    :param ignore_existing: If True, all existing files are ignored and not overwritten.
+    :param show_progress: If true, show a progressbar.
+    :param listener: An event-listener that is called with every update of rclone.
+    :param args: List of additional arguments/ flags.
+    """
+    if args is None:
+        args = []
+
     _rclone_transfer_operation(
         in_path,
         out_path,
@@ -181,6 +216,38 @@ def move(
     )
 
 
+def moveto(
+    in_path: str,
+    out_path: str,
+    ignore_existing=False,
+    show_progress=True,
+    listener: Callable[[Dict], None] = None,
+    args=None,
+):
+    """
+    Moves a file or a directory from a src path to a destination path and is typically used when renaming is necessary.
+    :param in_path: The source path to use. Specify the remote with 'remote_name:path_on_remote'
+    :param out_path: The destination path to use. Specify the remote with 'remote_name:path_on_remote'
+    :param ignore_existing: If True, all existing files are ignored and not overwritten.
+    :param show_progress: If true, show a progressbar.
+    :param listener: An event-listener that is called with every update of rclone.
+    :param args: List of additional arguments/ flags.
+    """
+    if args is None:
+        args = []
+
+    _rclone_transfer_operation(
+        in_path,
+        out_path,
+        ignore_existing=ignore_existing,
+        command="rclone moveto",
+        command_descr="Moving",
+        show_progress=show_progress,
+        listener=listener,
+        args=args,
+    )
+
+
 def sync(
     src_path: str,
     dest_path: str,
@@ -532,7 +599,7 @@ def _rclone_transfer_operation(
 
     # execute the upload command
     process = utils.rclone_progress(
-        command, prog_title, listener=listener, show_progress=show_progress
+        command, prog_title, listener=listener, show_progress=show_progress, debug=DEBUG
     )
 
     if process.wait() == 0:
